@@ -2,9 +2,10 @@
 
   Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -56,15 +57,6 @@ class Q_DECL_HIDDEN FolderTreeWidget::FolderTreeWidgetPrivate
 {
 public:
     FolderTreeWidgetPrivate()
-        : filterModel(nullptr)
-        , folderTreeView(nullptr)
-        , quotaModel(nullptr)
-        , readableproxy(nullptr)
-        , entityOrderProxy(nullptr)
-        , filterFolderLineEdit(nullptr)
-        , saver(nullptr)
-        , label(nullptr)
-        , dontKeyFilter(false)
     {
     }
 
@@ -113,11 +105,15 @@ FolderTreeWidget::FolderTreeWidget(
     d->quotaModel = new Akonadi::QuotaColorProxyModel(this);
     d->quotaModel->setSourceModel(KernelIf->collectionModel());
 
-    d->filterModel = new Akonadi::StatisticsProxyModel(this);
-    d->filterModel->setSourceModel(d->quotaModel);
+    if (!(options & HideStatistics)) {
+        d->filterModel = new Akonadi::StatisticsProxyModel(this);
+        d->filterModel->setSourceModel(d->quotaModel);
+    }
 
     d->readableproxy = new FolderTreeWidgetProxyModel(this, optReadableProxy);
-    d->readableproxy->setSourceModel(d->filterModel);
+    d->readableproxy->setSourceModel((options & HideStatistics)
+                                     ? static_cast<QAbstractItemModel *>(d->quotaModel)
+                                     : static_cast<QAbstractItemModel *>(d->filterModel));
     d->readableproxy->addContentMimeTypeInclusionFilter(KMime::Message::mimeType());
 
     connect(d->folderTreeView, &FolderTreeView::changeTooltipsPolicy, this, &FolderTreeWidget::slotChangeTooltipsPolicy);
@@ -240,7 +236,7 @@ Akonadi::Collection::List FolderTreeWidget::selectedCollections() const
         if (index.isValid()) {
             const Akonadi::Collection collection
                 = index.model()->data(
-                index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+                      index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (collection.isValid()) {
                 collections.append(collection);
             }
@@ -302,10 +298,14 @@ void FolderTreeWidget::changeToolTipsPolicyConfig(ToolTipDisplayPolicy policy)
     switch (policy) {
     case DisplayAlways:
     case DisplayWhenTextElided: //Need to implement in the future
-        d->filterModel->setToolTipEnabled(true);
+        if (d->filterModel) {
+            d->filterModel->setToolTipEnabled(true);
+        }
         break;
     case DisplayNever:
-        d->filterModel->setToolTipEnabled(false);
+        if (d->filterModel) {
+            d->filterModel->setToolTipEnabled(false);
+        }
     }
     d->folderTreeView->setTooltipsPolicy(policy);
 }
